# Test Coverage Report

Generated: Thu 2013-05-02 12:21 SGT

| Statements
--- | ---
Module | total | executed | excluded | % covered
Total | 492 | 392 | 56 | 89.9%
calendarium.__init__ | 1 | 0 | 0 | 0.0%
calendarium.constants | 5 | 4 | 1 | 100.0%
calendarium.forms | 70 | 51 | 6 | 79.7%
calendarium.models | 163 | 118 | 25 | 85.5%
calendarium.templatetags.calendarium_tags | 16 | 12 | 4 | 100.0%
calendarium.tests.test_app.models | 7 | 5 | 2 | 100.0%
calendarium.utils | 20 | 18 | 2 | 100.0%
calendarium.views | 197 | 178 | 13 | 96.7%
calendarium.widgets | 13 | 6 | 3 | 60.0%

Excluded packages and modules
Error packages and modules